@@ -4,16 +4,17 @@
 dt_subset <- function(dt, i, j, env = parent.frame(), sd_cols = NULL) {
   env <- new.env(parent = env, size = 2L)
   env$`_dt` <- dt
-  env$`_vars` <- deparse_all(groups(dt))
 
   args <- list(
-    i = if (missing(i)) quote(expr =) else dt_replace(i),
-    j = if (missing(j)) quote(expr =) else dt_replace(j)
+    i = if (missing(i)) missing_arg() else dt_replace(i),
+    j = if (missing(j)) missing_arg() else dt_replace(j)
   )
 
   if (missing(j)) {
+    # No need for `by` groups when subsetting rows
     call <- substitute(`_dt`[i], args)
   } else {
+    env$`_vars` <- dplyr::group_vars(dt)
     call <- substitute(`_dt`[i, j, by = `_vars`], args)
     call$.SDcols = sd_cols
   }
@@ -47,21 +48,10 @@ dt_replace <- function(x) {
 
 commas <- function(...) paste0(..., collapse = ", ")
 
-deparse_all <- function(x) {
-  deparse2 <- function(x) paste(deparse(x, width.cutoff = 500L), collapse = "")
-  vapply(x, deparse2, FUN.VALUE = character(1))
-}
-
-
 drop_last <- function(x) {
-  if (length(x) <= 1L) return(NULL)
+  if (length(x) <= 1L) {
+    return(NULL)
+  }
   x[-length(x)]
 }
 
-
-names2 <- function(x) {
-  names(x) %||% rep("", length(x))
-}
-
-"%||%" <- function(x, y) if(is.null(x)) y else x
-
